summaryrefslogtreecommitdiff
path: root/examples/v3arch/asyncore/agent/ntforg/send-packet-from-specific-address.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/v3arch/asyncore/agent/ntforg/send-packet-from-specific-address.py')
-rw-r--r--examples/v3arch/asyncore/agent/ntforg/send-packet-from-specific-address.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/v3arch/asyncore/agent/ntforg/send-packet-from-specific-address.py b/examples/v3arch/asyncore/agent/ntforg/send-packet-from-specific-address.py
index 68ce95c5..5b0f9f69 100644
--- a/examples/v3arch/asyncore/agent/ntforg/send-packet-from-specific-address.py
+++ b/examples/v3arch/asyncore/agent/ntforg/send-packet-from-specific-address.py
@@ -7,14 +7,14 @@ Send SNMP notification using the following options:
* SNMPv1
* with community name 'public'
* over IPv4/UDP
* to a Manager at 195.218.195.228 UDP port 162
* from local address 0.0.0.0, UDP port 61024
* send TRAP notification
* with TRAP ID 'coldStart' specified as an OID
Functionally similar to:
-| $ snmptrap -v1 -c public 195.218.195.228 1.3.6.1.6.3.1.1.5.1 0.0.0.0 1 0 0
+| $ snmptrap -v1 -c public 104.236.166.95 1.3.6.1.6.3.1.1.5.1 0.0.0.0 1 0 0
"""#
from pysnmp.entity import engine, config
@@ -42,7 +42,7 @@ config.addTransport(
)
config.addTargetAddr(
snmpEngine, 'my-nms',
- udp.domainName, ('195.218.195.228', 162),
+ udp.domainName, ('104.236.166.95', 162),
'my-creds',
tagList='all-my-managers'
)
@@ -7,14 +7,14 @@ Send SNMP notification using the following options:
* with community name 'public'
* over IPv4/UDP
-* to a Manager at 195.218.195.228 UDP port 162
+* to a Manager at 104.236.166.95 UDP port 162
* from local address 0.0.0.0, UDP port 61024
* send TRAP notification